# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import printnanny_api_client
from printnanny_api_client.api.devices_api import DevicesApi  # noqa: E501
from printnanny_api_client.rest import ApiException


class TestDevicesApi(unittest.TestCase):
    """DevicesApi unit test stubs"""

    def setUp(self):
        self.api = printnanny_api_client.api.devices_api.DevicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_device_info_update_or_create(self):
        """Test case for device_info_update_or_create

        """
        pass

    def test_devices_active_license_retrieve(self):
        """Test case for devices_active_license_retrieve

        """
        pass

    def test_devices_cameras_create(self):
        """Test case for devices_cameras_create

        """
        pass

    def test_devices_cameras_list(self):
        """Test case for devices_cameras_list

        """
        pass

    def test_devices_cameras_partial_update(self):
        """Test case for devices_cameras_partial_update

        """
        pass

    def test_devices_cameras_retrieve(self):
        """Test case for devices_cameras_retrieve

        """
        pass

    def test_devices_cameras_update(self):
        """Test case for devices_cameras_update

        """
        pass

    def test_devices_cloud_iot_devices_create(self):
        """Test case for devices_cloud_iot_devices_create

        """
        pass

    def test_devices_cloud_iot_devices_list(self):
        """Test case for devices_cloud_iot_devices_list

        """
        pass

    def test_devices_cloud_iot_devices_partial_update(self):
        """Test case for devices_cloud_iot_devices_partial_update

        """
        pass

    def test_devices_cloud_iot_devices_retrieve(self):
        """Test case for devices_cloud_iot_devices_retrieve

        """
        pass

    def test_devices_cloud_iot_devices_update(self):
        """Test case for devices_cloud_iot_devices_update

        """
        pass

    def test_devices_create(self):
        """Test case for devices_create

        """
        pass

    def test_devices_generate_license(self):
        """Test case for devices_generate_license

        """
        pass

    def test_devices_info_create(self):
        """Test case for devices_info_create

        """
        pass

    def test_devices_info_list(self):
        """Test case for devices_info_list

        """
        pass

    def test_devices_info_partial_update(self):
        """Test case for devices_info_partial_update

        """
        pass

    def test_devices_info_retrieve(self):
        """Test case for devices_info_retrieve

        """
        pass

    def test_devices_info_update(self):
        """Test case for devices_info_update

        """
        pass

    def test_devices_list(self):
        """Test case for devices_list

        """
        pass

    def test_devices_partial_update(self):
        """Test case for devices_partial_update

        """
        pass

    def test_devices_printer_controllers_create(self):
        """Test case for devices_printer_controllers_create

        """
        pass

    def test_devices_printer_controllers_list(self):
        """Test case for devices_printer_controllers_list

        """
        pass

    def test_devices_printer_controllers_partial_update(self):
        """Test case for devices_printer_controllers_partial_update

        """
        pass

    def test_devices_printer_controllers_retrieve(self):
        """Test case for devices_printer_controllers_retrieve

        """
        pass

    def test_devices_printer_controllers_update(self):
        """Test case for devices_printer_controllers_update

        """
        pass

    def test_devices_retrieve(self):
        """Test case for devices_retrieve

        """
        pass

    def test_devices_retrieve_hostname(self):
        """Test case for devices_retrieve_hostname

        """
        pass

    def test_devices_tasks_create(self):
        """Test case for devices_tasks_create

        """
        pass

    def test_devices_tasks_list(self):
        """Test case for devices_tasks_list

        """
        pass

    def test_devices_tasks_retrieve(self):
        """Test case for devices_tasks_retrieve

        """
        pass

    def test_devices_tasks_status_create(self):
        """Test case for devices_tasks_status_create

        """
        pass

    def test_devices_tasks_status_list(self):
        """Test case for devices_tasks_status_list

        """
        pass

    def test_devices_tasks_status_retrieve(self):
        """Test case for devices_tasks_status_retrieve

        """
        pass

    def test_devices_update(self):
        """Test case for devices_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
