# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import printnanny_api_client
from printnanny_api_client.api.partners_geeks3_api import PartnersGeeks3Api  # noqa: E501
from printnanny_api_client.rest import ApiException


class TestPartnersGeeks3Api(unittest.TestCase):
    """PartnersGeeks3Api unit test stubs"""

    def setUp(self):
        self.api = printnanny_api_client.api.partners_geeks3_api.PartnersGeeks3Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_alerts_list2(self):
        """Test case for alerts_list2

        """
        pass


if __name__ == '__main__':
    unittest.main()
