# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class CameraRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'active': 'bool',
        'device': 'int',
        'name': 'str',
        'camera_type': 'CameraType'
    }

    attribute_map = {
        'active': 'active',
        'device': 'device',
        'name': 'name',
        'camera_type': 'camera_type'
    }

    def __init__(self, active=None, device=None, name='Raspberry Pi Cam', camera_type=None, local_vars_configuration=None):  # noqa: E501
        """CameraRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._active = None
        self._device = None
        self._name = None
        self._camera_type = None
        self.discriminator = None

        if active is not None:
            self.active = active
        self.device = device
        if name is not None:
            self.name = name
        self.camera_type = camera_type

    @property
    def active(self):
        """Gets the active of this CameraRequest.  # noqa: E501


        :return: The active of this CameraRequest.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this CameraRequest.


        :param active: The active of this CameraRequest.  # noqa: E501
        :type active: bool
        """

        self._active = active

    @property
    def device(self):
        """Gets the device of this CameraRequest.  # noqa: E501


        :return: The device of this CameraRequest.  # noqa: E501
        :rtype: int
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this CameraRequest.


        :param device: The device of this CameraRequest.  # noqa: E501
        :type device: int
        """
        if self.local_vars_configuration.client_side_validation and device is None:  # noqa: E501
            raise ValueError("Invalid value for `device`, must not be `None`")  # noqa: E501

        self._device = device

    @property
    def name(self):
        """Gets the name of this CameraRequest.  # noqa: E501

        Descriptive name to identify this camera  # noqa: E501

        :return: The name of this CameraRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CameraRequest.

        Descriptive name to identify this camera  # noqa: E501

        :param name: The name of this CameraRequest.  # noqa: E501
        :type name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def camera_type(self):
        """Gets the camera_type of this CameraRequest.  # noqa: E501


        :return: The camera_type of this CameraRequest.  # noqa: E501
        :rtype: CameraType
        """
        return self._camera_type

    @camera_type.setter
    def camera_type(self, camera_type):
        """Sets the camera_type of this CameraRequest.


        :param camera_type: The camera_type of this CameraRequest.  # noqa: E501
        :type camera_type: CameraType
        """

        self._camera_type = camera_type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CameraRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CameraRequest):
            return True

        return self.to_dict() != other.to_dict()
