# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.patched_octo_print_device_request import PatchedOctoPrintDeviceRequest  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPatchedOctoPrintDeviceRequest(unittest.TestCase):
    """PatchedOctoPrintDeviceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PatchedOctoPrintDeviceRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.patched_octo_print_device_request.PatchedOctoPrintDeviceRequest()  # noqa: E501
        if include_optional :
            return PatchedOctoPrintDeviceRequest(
                name = '0', 
                model = '0', 
                platform = '0', 
                cpu_flags = [
                    '0'
                    ], 
                hardware = '0', 
                revision = '0', 
                serial = '0', 
                cores = -2147483648, 
                ram = -2147483648, 
                python_version = '0', 
                pip_version = '0', 
                virtualenv = '0', 
                octoprint_version = '0', 
                plugin_version = '0', 
                print_nanny_client_version = '0', 
                print_nanny_beta_client_version = '0', 
                active_session = printnanny_api_client.models.print_session_request.PrintSessionRequest(
                    created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    octoprint_device = 56, 
                    active = True, 
                    session = '0', 
                    filepos = -2147483648, 
                    print_progress = -2147483648, 
                    time_elapsed = -2147483648, 
                    time_remaining = -2147483648, 
                    printer_profile = 56, 
                    gcode_file = 56, 
                    gcode_filename = '0', 
                    octoprint_job = {
                        'key' : null
                        }, 
                    print_job_status = null, )
            )
        else :
            return PatchedOctoPrintDeviceRequest(
        )

    def testPatchedOctoPrintDeviceRequest(self):
        """Test PatchedOctoPrintDeviceRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
