# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.octoprint_environment import OctoprintEnvironment  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestOctoprintEnvironment(unittest.TestCase):
    """OctoprintEnvironment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OctoprintEnvironment
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.octoprint_environment.OctoprintEnvironment()  # noqa: E501
        if include_optional :
            return OctoprintEnvironment(
                os = printnanny_api_client.models.octoprint_platform.OctoprintPlatform(
                    id = '', 
                    platform = '', 
                    bits = '', ), 
                python = printnanny_api_client.models.octoprint_python.OctoprintPython(
                    version = '', 
                    pip = '', 
                    virtualenv = '', ), 
                hardware = printnanny_api_client.models.octoprint_hardware.OctoprintHardware(
                    cores = 56, 
                    freq = 1.337, 
                    ram = 56, ), 
                pi_support = printnanny_api_client.models.octoprint_pi_support.OctoprintPiSupport(
                    model = '', 
                    throttle_state = '', 
                    octopi_version = '', )
            )
        else :
            return OctoprintEnvironment(
                os = printnanny_api_client.models.octoprint_platform.OctoprintPlatform(
                    id = '', 
                    platform = '', 
                    bits = '', ),
                python = printnanny_api_client.models.octoprint_python.OctoprintPython(
                    version = '', 
                    pip = '', 
                    virtualenv = '', ),
                hardware = printnanny_api_client.models.octoprint_hardware.OctoprintHardware(
                    cores = 56, 
                    freq = 1.337, 
                    ram = 56, ),
                pi_support = printnanny_api_client.models.octoprint_pi_support.OctoprintPiSupport(
                    model = '', 
                    throttle_state = '', 
                    octopi_version = '', ),
        )

    def testOctoprintEnvironment(self):
        """Test OctoprintEnvironment"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
