# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import printnanny_api_client
from printnanny_api_client.api.ml_ops_api import MlOpsApi  # noqa: E501
from printnanny_api_client.rest import ApiException


class TestMlOpsApi(unittest.TestCase):
    """MlOpsApi unit test stubs"""

    def setUp(self):
        self.api = printnanny_api_client.api.ml_ops_api.MlOpsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_device_calibration_update_or_create(self):
        """Test case for device_calibration_update_or_create

        """
        pass

    def test_device_calibrations_list(self):
        """Test case for device_calibrations_list

        """
        pass

    def test_device_calibrations_partial_update(self):
        """Test case for device_calibrations_partial_update

        """
        pass

    def test_device_calibrations_retrieve(self):
        """Test case for device_calibrations_retrieve

        """
        pass

    def test_device_calibrations_update(self):
        """Test case for device_calibrations_update

        """
        pass

    def test_experiment_device_configs_list(self):
        """Test case for experiment_device_configs_list

        """
        pass

    def test_experiment_device_configs_retrieve(self):
        """Test case for experiment_device_configs_retrieve

        """
        pass

    def test_experiments_list(self):
        """Test case for experiments_list

        """
        pass

    def test_experiments_retrieve(self):
        """Test case for experiments_retrieve

        """
        pass

    def test_model_artifacts_list(self):
        """Test case for model_artifacts_list

        """
        pass

    def test_model_artifacts_retrieve(self):
        """Test case for model_artifacts_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
