# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoprintPiSupportRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'model': 'str',
        'throttle_state': 'str',
        'octopi_version': 'str'
    }

    attribute_map = {
        'model': 'model',
        'throttle_state': 'throttle_state',
        'octopi_version': 'octopi_version'
    }

    def __init__(self, model=None, throttle_state=None, octopi_version=None, local_vars_configuration=None):  # noqa: E501
        """OctoprintPiSupportRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._model = None
        self._throttle_state = None
        self._octopi_version = None
        self.discriminator = None

        self.model = model
        self.throttle_state = throttle_state
        if octopi_version is not None:
            self.octopi_version = octopi_version

    @property
    def model(self):
        """Gets the model of this OctoprintPiSupportRequest.  # noqa: E501


        :return: The model of this OctoprintPiSupportRequest.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this OctoprintPiSupportRequest.


        :param model: The model of this OctoprintPiSupportRequest.  # noqa: E501
        :type model: str
        """
        if self.local_vars_configuration.client_side_validation and model is None:  # noqa: E501
            raise ValueError("Invalid value for `model`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                model is not None and len(model) < 1):
            raise ValueError("Invalid value for `model`, length must be greater than or equal to `1`")  # noqa: E501

        self._model = model

    @property
    def throttle_state(self):
        """Gets the throttle_state of this OctoprintPiSupportRequest.  # noqa: E501


        :return: The throttle_state of this OctoprintPiSupportRequest.  # noqa: E501
        :rtype: str
        """
        return self._throttle_state

    @throttle_state.setter
    def throttle_state(self, throttle_state):
        """Sets the throttle_state of this OctoprintPiSupportRequest.


        :param throttle_state: The throttle_state of this OctoprintPiSupportRequest.  # noqa: E501
        :type throttle_state: str
        """
        if self.local_vars_configuration.client_side_validation and throttle_state is None:  # noqa: E501
            raise ValueError("Invalid value for `throttle_state`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                throttle_state is not None and len(throttle_state) < 1):
            raise ValueError("Invalid value for `throttle_state`, length must be greater than or equal to `1`")  # noqa: E501

        self._throttle_state = throttle_state

    @property
    def octopi_version(self):
        """Gets the octopi_version of this OctoprintPiSupportRequest.  # noqa: E501


        :return: The octopi_version of this OctoprintPiSupportRequest.  # noqa: E501
        :rtype: str
        """
        return self._octopi_version

    @octopi_version.setter
    def octopi_version(self, octopi_version):
        """Sets the octopi_version of this OctoprintPiSupportRequest.


        :param octopi_version: The octopi_version of this OctoprintPiSupportRequest.  # noqa: E501
        :type octopi_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                octopi_version is not None and len(octopi_version) < 1):
            raise ValueError("Invalid value for `octopi_version`, length must be greater than or equal to `1`")  # noqa: E501

        self._octopi_version = octopi_version

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoprintPiSupportRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoprintPiSupportRequest):
            return True

        return self.to_dict() != other.to_dict()
